@@ -3,10 +3,11 @@
 test_that(
   desc = "`grouped_tidy()` works",
   code = {
+    options(tibble.width = Inf)
     library(lme4)
-    set.seed(123)
 
     # broom.mixed
+    set.seed(123)
     lmer_df <-
       broomExtra::grouped_tidy(
         data = dplyr::mutate(MASS::Aids2, interval = death - diag),
@@ -17,8 +18,8 @@ test_that(
         tidy.args = list(conf.int = TRUE, conf.level = 0.99)
       )
 
-
     # broom
+    set.seed(123)
     lm_df <-
       broomExtra::grouped_tidy(
         data = dplyr::mutate(MASS::Aids2, interval = death - diag),
@@ -30,6 +31,8 @@ test_that(
 
     expect_equal(dim(lmer_df), c(8L, 9L))
     expect_equal(dim(lm_df), c(4L, 8L))
+
+    expect_snapshot(list(lmer_df, lm_df))
   }
 )
 
@@ -42,6 +45,7 @@ test_that(
     set.seed(123)
 
     # broom.mixed
+    set.seed(123)
     lmer_df <-
       broomExtra::grouped_glance(
         data = dplyr::mutate(MASS::Aids2, interval = death - diag),
@@ -52,6 +56,7 @@ test_that(
       )
 
     # broom
+    set.seed(123)
     lm_df <-
       broomExtra::grouped_glance(
         data = dplyr::mutate(MASS::Aids2, interval = death - diag),
@@ -62,6 +67,8 @@ test_that(
 
     expect_equal(dim(lmer_df), c(2L, 7L))
     expect_equal(dim(lm_df)[1], 2L)
+
+    expect_snapshot(list(lmer_df, lm_df))
   }
 )
 
@@ -71,9 +78,9 @@ test_that(
   desc = "`grouped_augment()` works",
   code = {
     library(lme4)
-    set.seed(123)
 
     # broom.mixed
+    set.seed(123)
     lmer_df <-
       broomExtra::grouped_augment(
         data = dplyr::mutate(MASS::Aids2, interval = death - diag),
@@ -84,6 +91,7 @@ test_that(
       )
 
     # broom
+    set.seed(123)
     lm_df <-
       broomExtra::grouped_augment(
         data = dplyr::mutate(MASS::Aids2, interval = death - diag),
